@@ -1,11 +1,11 @@
 use 5.008001; # sane UTF-8 support
 use strict;
 use warnings;
-package CPAN::Meta::YAML; # git description: v1.65-6-gfa117d1
+package CPAN::Meta::YAML; # git description: v1.74-6-g56f1f15
 # XXX-INGY is 5.8.1 too old/broken for utf8?
 # XXX-XDG Lancaster consensus was that it was sufficient until
 # proven otherwise
-$CPAN::Meta::YAML::VERSION = '0.014';
+$CPAN::Meta::YAML::VERSION = '0.019';
 ; # original $VERSION removed by Doppelgaenger
 
 #####################################################################
@@ -138,7 +138,10 @@ my %UNESCAPES = (
 # These 3 values have special meaning when unquoted and using the
 # default YAML schema. They need quotes if they are strings.
 my %QUOTE = map { $_ => 1 } qw{
-    null true false
+    null Null NULL
+    y Y yes Yes YES n N no No NO
+    true True TRUE false False FALSE
+    on On ON off Off OFF
 };
 
 # The commented out form is simpler, but overloaded the Perl regex
@@ -373,7 +376,7 @@ sub _load_scalar {
     while ( @$lines ) {
         $lines->[0] =~ /^(\s*)/;
         last unless length($1) >= $indent->[-1];
-        push @multiline, substr(shift(@$lines), length($1));
+        push @multiline, substr(shift(@$lines), $indent->[-1]);
     }
 
     my $j = (substr($string, 0, 1) eq '>') ? ' ' : "\n";
@@ -512,7 +515,7 @@ sub _load_hash {
         }
 
         if ( exists $hash->{$key} ) {
-            die \"CPAN::Meta::YAML found a duplicate key '$key' in line '$lines->[0]'";
+            warn "CPAN::Meta::YAML found a duplicate key '$key' in line '$lines->[0]'";
         }
 
         # Do we have a value?
@@ -569,10 +572,8 @@ sub _dump_file {
     if ( _can_flock() ) {
         # Open without truncation (truncate comes after lock)
         my $flags = Fcntl::O_WRONLY()|Fcntl::O_CREAT();
-        sysopen( $fh, $file, $flags );
-        unless ( $fh ) {
-            $self->_error("Failed to open file '$file' for writing: $!");
-        }
+        sysopen( $fh, $file, $flags )
+            or $self->_error("Failed to open file '$file' for writing: $!");
 
         # Use no translation and strict UTF-8
         binmode( $fh, ":raw:encoding(UTF-8)");
@@ -878,7 +879,7 @@ CPAN::Meta::YAML - Read and write a subset of YAML for CPAN Meta files
 
 =head1 VERSION
 
-version 0.014
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -934,6 +935,12 @@ David Golden <dagolden@cpan.org>
 
 =back
 
+=head1 CONTRIBUTOR
+
+=for stopwords Karen Etheridge
+
+Karen Etheridge <ether@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2010 by Adam Kennedy.
